tw2.sqla
========

.. split here

tw2.sqla is a database layer for ToscaWidgets 2 and SQLAlchemy. It allows common database tasks to be achieved with minimal code.

Build Status
------------

.. |master| image:: https://secure.travis-ci.org/toscawidgets/tw2.sqla.png?branch=master
   :alt: Build Status - master branch
   :target: http://travis-ci.org/#!/toscawidgets/tw2.sqla

.. |develop| image:: https://secure.travis-ci.org/toscawidgets/tw2.sqla.png?branch=develop
   :alt: Build Status - develop branch
   :target: http://travis-ci.org/#!/toscawidgets/tw2.sqla

+----------+-----------+
| Branch   | Status    |
+==========+===========+
| master   | |master|  |
+----------+-----------+
| develop  | |develop| |
+----------+-----------+
